@@ -22,54 +22,14 @@ Various useful plugins for working with bzr.
 
 import bzrlib
 
-
-__version__ = '0.15.4'
-
-
-version_info = tuple(int(n) for n in __version__.split('.'))
-
-
-def check_bzrlib_version(desired):
-    """Check that bzrlib is compatible.
-
-    If version is < bzrtools version, assume incompatible.
-    If version == bzrtools version, assume completely compatible
-    If version == bzrtools version + 1, assume compatible, with deprecations
-    Otherwise, assume incompatible.
-    """
-    desired_plus = (desired[0], desired[1]+1)
-    bzrlib_version = bzrlib.version_info[:2]
-    if bzrlib_version == desired:
-        return
-    try:
-        from bzrlib.trace import warning
-    except ImportError:
-        # get the message out any way we can
-        from warnings import warn as warning
-    if bzrlib_version < desired:
-        warning('Installed Bazaar version %s is too old to be used with'
-                ' plugin \n'
-                '"Bzrtools" %s.' % (bzrlib.__version__, __version__))
-        # Not using BzrNewError, because it may not exist.
-        raise Exception, ('Version mismatch', version_info)
-    else:
-        warning('Plugin "Bzrtools" is not up to date with installed Bazaar'
-                ' version %s.\n'
-                ' There should be a newer version of Bzrtools available, e.g.'
-                ' %i.%i.'
-                % (bzrlib.__version__, bzrlib_version[0], bzrlib_version[1]))
-        if bzrlib_version != desired_plus:
-            raise Exception, 'Version mismatch'
-
-
-check_bzrlib_version(version_info[:2])
-
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 from bzrlib import help
 import shelf
 """)
 
+from version import version_info, __version__
+from command import BzrToolsCommand
 from errors import CommandError, NoPyBaz
 from patchsource import BzrPatchSource
 import sys
@@ -81,15 +41,16 @@ from bzrlib.commands import get_cmd_object
 from bzrlib.errors import BzrCommandError
 import bzrlib.ignores
 from bzrlib.option import Option
-sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__), 
+sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__),
                                                  "external")))
 
 import show_paths
+from command import BzrToolsCommand
 
 bzrlib.ignores.add_runtime_ignores(['./.shelf'])
 
 
-class cmd_clean_tree(bzrlib.commands.Command):
+class cmd_clean_tree(BzrToolsCommand):
     """Remove unwanted files from working tree.
 
     By default, only unknown files, not ignored files, are deleted.  Versioned
@@ -104,12 +65,12 @@ class cmd_clean_tree(bzrlib.commands.Command):
 
     To check what clean-tree will do, use --dry-run.
     """
-    takes_options = [Option('ignored', help='delete all ignored files.'), 
-                     Option('detritus', help='delete conflict files, merge'
-                            ' backups, and failed selftest dirs.'), 
-                     Option('unknown', 
-                            help='delete files unknown to bzr.  (default)'),
-                     Option('dry-run', help='show files to delete instead of'
+    takes_options = [Option('ignored', help='Delete all ignored files.'),
+                     Option('detritus', help='Delete conflict files, merge'
+                            ' backups, and failed selftest dirs.'),
+                     Option('unknown',
+                            help='Delete files unknown to bzr (default).'),
+                     Option('dry-run', help='Show files to delete instead of'
                             ' deleting them.')]
     def run(self, unknown=False, ignored=False, detritus=False, dry_run=False):
         from clean_tree import clean_tree
@@ -119,7 +80,7 @@ class cmd_clean_tree(bzrlib.commands.Command):
                    dry_run=dry_run)
 
 
-class cmd_graph_ancestry(bzrlib.commands.Command):
+class cmd_graph_ancestry(BzrToolsCommand):
     """Produce ancestry graphs using dot.
     
     Output format is detected according to file extension.  Some of the more
@@ -131,10 +92,10 @@ class cmd_graph_ancestry(bzrlib.commands.Command):
     with the last 5 characters of their revision identifier are used instead.
 
     The value starting with d is "(maximum) distance from the null revision".
-    
+
     If --merge-branch is specified, the two branches are compared and a merge
     base is selected.
-    
+
     Legend:
     white    normal revision
     yellow   THIS  history
@@ -154,34 +115,43 @@ class cmd_graph_ancestry(bzrlib.commands.Command):
     If available, rsvg is used to antialias PNG and JPEG output, but this can
     be disabled with --no-antialias.
     """
-    takes_args = ['branch', 'file']
-    takes_options = [Option('no-collapse', help="Do not skip simple nodes"), 
+    takes_args = ['file', 'merge_branch?']
+    takes_options = [Option('no-collapse', help="Do not skip simple nodes."),
                      Option('no-antialias',
-                     help="Do not use rsvg to produce antialiased output"), 
-                     Option('merge-branch', type=str, 
-                     help="Use this branch to calcuate a merge base"), 
+                     help="Do not use rsvg to produce antialiased output."),
+                     Option('merge-branch', type=str,
+                     help="Use this branch to calcuate a merge base."),
                      Option('cluster', help="Use clustered output."),
-                     Option('max-distance', help="Show no nodes farther than this",
-                            type=int)]
-    def run(self, branch, file, no_collapse=False, no_antialias=False,
-        merge_branch=None, cluster=False, max_distance=None):
+                     Option('max-distance',
+                            help="Show no nodes farther than this.", type=int),
+                     Option('directory',
+                            help='Source branch to use (default is current'
+                            ' directory).',
+                            short_name='d',
+                            type=unicode),
+                    ]
+    def run(self, file, merge_branch=None, no_collapse=False,
+            no_antialias=False, cluster=False, max_distance=100,
+            directory='.'):
+        if max_distance == -1:
+            max_distance = None
         import graph
         if cluster:
             ranking = "cluster"
         else:
             ranking = "forced"
-        graph.write_ancestry_file(branch, file, not no_collapse, 
-                                  not no_antialias, merge_branch, ranking, 
+        graph.write_ancestry_file(directory, file, not no_collapse,
+                                  not no_antialias, merge_branch, ranking,
                                   max_distance=max_distance)
 
 
-class cmd_fetch_ghosts(bzrlib.commands.Command):
+class cmd_fetch_ghosts(BzrToolsCommand):
     """Attempt to retrieve ghosts from another branch.
     If the other branch is not supplied, the last-pulled branch is used.
     """
     aliases = ['fetch-missing']
     takes_args = ['branch?']
-    takes_options = [Option('no-fix')]
+    takes_options = [Option('no-fix', help="Skip additional synchonization.")]
     def run(self, branch=None, no_fix=False):
         from fetch_ghosts import fetch_ghosts
         fetch_ghosts(branch, no_fix)
@@ -190,12 +160,12 @@ strip_help="""Strip the smallest prefix containing num leading slashes  from \
 each file name found in the patch file."""
 
 
-class cmd_patch(bzrlib.commands.Command):
+class cmd_patch(BzrToolsCommand):
     """Apply a named patch to the current tree.
     """
     takes_args = ['filename?']
     takes_options = [Option('strip', type=int, help=strip_help),
-                     Option('silent', help='Suppress chatter')]
+                     Option('silent', help='Suppress chatter.')]
     def run(self, filename=None, strip=None, silent=False):
         from patch import patch
         from bzrlib.workingtree import WorkingTree
@@ -205,7 +175,7 @@ class cmd_patch(bzrlib.commands.Command):
         return patch(wt, filename, strip, silent)
 
 
-class cmd_shelve(bzrlib.commands.Command):
+class cmd_shelve(BzrToolsCommand):
     """Temporarily set aside some changes from the current tree.
 
     Shelve allows you to temporarily put changes you've made "on the shelf",
@@ -236,9 +206,12 @@ class cmd_shelve(bzrlib.commands.Command):
     """
 
     takes_args = ['file*']
-    takes_options = ['message', 'revision',
-            Option('all', help='Shelve all changes without prompting'), 
-            Option('no-color', help='Never display changes in color')]
+    takes_options = [Option('message',
+            help='A message to associate with the shelved changes.',
+            short_name='m', type=unicode),
+            'revision',
+            Option('all', help='Shelve all changes without prompting.'),
+            Option('no-color', help='Never display changes in color.')]
 
     def run(self, all=False, file_list=None, message=None, revision=None,
             no_color=False):
@@ -297,7 +270,7 @@ class cmd_shelf_upgrade(bzrlib.commands.Command):
         self.shelf.upgrade()
 
 
-class cmd_shelf(bzrlib.commands.Command):
+class cmd_shelf(BzrToolsCommand):
     """Perform various operations on your shelved patches. See also shelve."""
     takes_args = ['subcommand', 'args*']
 
@@ -338,7 +311,7 @@ class cmd_shelf(bzrlib.commands.Command):
         cmd_obj = cmd_class()
         indent = 2 * ' '
 
-        usage = help.command_usage(cmd_obj)
+        usage = cmd_obj._usage()
         usage = usage.replace('bzr shelf-', '')
         text.append('%s%s\n' % (indent, usage))
 
@@ -363,7 +336,7 @@ class cmd_shelf(bzrlib.commands.Command):
         return text
 
 
-class cmd_unshelve(bzrlib.commands.Command):
+class cmd_unshelve(BzrToolsCommand):
     """Restore shelved changes.
 
     By default the most recently shelved changes are restored. However if you
@@ -372,9 +345,9 @@ class cmd_unshelve(bzrlib.commands.Command):
     See 'shelve' for more information.
     """
     takes_options = [
-            Option('all', help='Unshelve all changes without prompting'),
-            Option('force', help='Force unshelving even if errors occur'),
-            Option('no-color', help='Never display changes in color')
+            Option('all', help='Unshelve all changes without prompting.'),
+            Option('force', help='Force unshelving even if errors occur.'),
+            Option('no-color', help='Never display changes in color.')
         ]
     takes_args = ['patch?']
     def run(self, patch=None, all=False, force=False, no_color=False):
@@ -384,7 +357,7 @@ class cmd_unshelve(bzrlib.commands.Command):
         return 0
 
 
-class cmd_shell(bzrlib.commands.Command):
+class cmd_shell(BzrToolsCommand):
     """Begin an interactive shell tailored for bzr.
     Bzr commands can be used without typing bzr first, and will be run natively
     when possible.  Tab completion is tailored for bzr.  The shell prompt shows
@@ -407,7 +380,7 @@ class cmd_shell(bzrlib.commands.Command):
         return shell.run_shell()
 
 
-class cmd_branch_history(bzrlib.commands.Command):
+class cmd_branch_history(BzrToolsCommand):
     """\
     Display the development history of a branch.
 
@@ -417,11 +390,11 @@ class cmd_branch_history(bzrlib.commands.Command):
     """
     takes_args = ["branch?"]
     def run(self, branch=None):
-        from branchhistory import branch_history 
+        from branchhistory import branch_history
         return branch_history(branch)
 
 
-class cmd_zap(bzrlib.commands.Command):
+class cmd_zap(BzrToolsCommand):
     """\
     Remove a lightweight checkout, if it can be done safely.
 
@@ -432,18 +405,18 @@ class cmd_zap(bzrlib.commands.Command):
     If --branch is specified, the branch will be deleted too, but only if the
     the branch has no new commits (relative to its parent).
     """
-    takes_options = [Option("branch", help="Remove associtated branch from"
-                                           " repository")]
+    takes_options = [Option("branch", help="Remove associated branch from"
+                                           " repository.")]
     takes_args = ["checkout"]
     def run(self, checkout, branch=False):
         from zap import zap
         return zap(checkout, remove_branch=branch)
 
 
-class cmd_cbranch(bzrlib.commands.Command):
+class cmd_cbranch(BzrToolsCommand):
     """
     Create a new checkout, associated with a new repository branch.
-    
+
     When you cbranch, bzr looks up a target location in locations.conf, and
     creates the branch there.
 
@@ -453,22 +426,22 @@ class cmd_cbranch(bzrlib.commands.Command):
     cbranch_target:policy = appendpath
 
     This will mean that if you run "bzr cbranch foo/bar foo/baz" in the
-    working directory root, the branch will be created in 
+    working directory root, the branch will be created in
     "/branch_root/foo/baz"
 
     NOTE: cbranch also supports "cbranch_root", but that behaviour is
     deprecated.
     """
-    takes_options = [Option("lightweight", 
-                            help="Create a lightweight checkout"), 'revision']
+    takes_options = [Option("lightweight",
+                            help="Create a lightweight checkout."), 'revision']
     takes_args = ["source", "target?"]
     def run(self, source, target=None, lightweight=False, revision=None):
         from cbranch import cbranch
-        return cbranch(source, target, lightweight=lightweight, 
+        return cbranch(source, target, lightweight=lightweight,
                        revision=revision)
 
 
-class cmd_branches(bzrlib.commands.Command):
+class cmd_branches(BzrToolsCommand):
     """Scan a location for branches"""
     takes_args = ["location?"]
     def run(self, location=None):
@@ -476,9 +449,9 @@ class cmd_branches(bzrlib.commands.Command):
         return branches(location)
 
 
-class cmd_multi_pull(bzrlib.commands.Command):
+class cmd_multi_pull(BzrToolsCommand):
     """Pull all the branches under a location, e.g. a repository.
-    
+
     Both branches present in the directory and the branches of checkouts are
     pulled.
     """
@@ -490,6 +463,7 @@ class cmd_multi_pull(bzrlib.commands.Command):
         if location is None:
             location = '.'
         t = get_transport(location)
+        possible_transports = []
         if not t.listable():
             print "Can't list this type of location."
             return 3
@@ -511,12 +485,13 @@ class cmd_multi_pull(bzrlib.commands.Command):
                 relpath = base
             print "Pulling %s from %s" % (relpath, parent)
             try:
-                pullable.pull(Branch.open(parent))
+                branch_t = get_transport(parent, possible_transports)
+                pullable.pull(Branch.open_from_transport(branch_t))
             except Exception, e:
                 print e
 
 
-class cmd_branch_mark(bzrlib.commands.Command):
+class cmd_branch_mark(BzrToolsCommand):
     """
     Add, view or list branch markers <EXPERIMENTAL>
 
@@ -528,15 +503,15 @@ class cmd_branch_mark(bzrlib.commands.Command):
     These marks can be used to track a branch's status.
     """
     takes_args = ['mark?', 'branch?']
-    takes_options = [Option('delete', help='Delete this mark')]
+    takes_options = [Option('delete', help='Delete this mark.')]
     def run(self, mark=None, branch=None, delete=False):
         from branch_mark import branch_mark
         branch_mark(mark, branch, delete)
 
 
-class cmd_import(bzrlib.commands.Command):
+class cmd_import(BzrToolsCommand):
     """Import sources from a directory, tarball or zip file
-    
+
     This command will import a directory, tarball or zip file into a bzr
     tree, replacing any versioned files already present.  If a directory is
     specified, it is used as the target.  If the directory does not exist, or
@@ -547,40 +522,35 @@ class cmd_import(bzrlib.commands.Command):
     If the tarball or zip has a single root directory, that directory is
     stripped when extracting the tarball.  This is not done for directories.
     """
-    
+
     takes_args = ['source', 'tree?']
     def run(self, source, tree=None):
         from upstream_import import do_import
         do_import(source, tree)
 
 
-class cmd_cdiff(bzrlib.commands.Command):
+class cmd_cdiff(BzrToolsCommand):
     """A color version of bzr's diff"""
     takes_args = property(lambda x: get_cmd_object('diff').takes_args)
-
-    def _takes_options(self):
-        options = list(get_cmd_object('diff').takes_options)
-        options.append(Option('check-style',
+    takes_options = list(get_cmd_object('diff').takes_options) + [
+        Option('check-style',
             help='Warn if trailing whitespace or spurious changes have been'
-                 ' added.'))
-        return options
-
-    takes_options = property(_takes_options)
+                 ' added.')]
 
     def run(self, check_style=False, *args, **kwargs):
         from colordiff import colordiff
         colordiff(check_style, *args, **kwargs)
 
 
-class cmd_baz_import(bzrlib.commands.Command):
+class cmd_baz_import(BzrToolsCommand):
     """Import an Arch or Baz archive into a bzr repository.
 
     This command should be used on local archives (or mirrors) only.  It is
     quite slow on remote archives.
-    
-    reuse_history allows you to specify any previous imports you 
+
+    reuse_history allows you to specify any previous imports you
     have done of different archives, which this archive has branches
-    tagged from. This will dramatically reduce the time to convert 
+    tagged from. This will dramatically reduce the time to convert
     the archive as it will not have to convert the history already
     converted in that other branch.
 
@@ -599,8 +569,8 @@ class cmd_baz_import(bzrlib.commands.Command):
     """
     takes_args = ['to_root_dir', 'from_archive', 'reuse_history*']
     takes_options = ['verbose', Option('prefixes', type=str,
-                     help="Prefixes of branches to import, colon-separated"),
-                     Option('encoding', type=str, 
+                     help="Prefixes of branches to import, colon-separated."),
+                     Option('encoding', type=str,
                      help='Force encoding to specified value.  See WARNING.')]
 
     def run(self, to_root_dir, from_archive, encoding=None, verbose=False,
@@ -614,7 +584,7 @@ class cmd_baz_import(bzrlib.commands.Command):
             print "This command is disabled.  Please install PyBaz."
 
 
-class cmd_baz_import_branch(bzrlib.commands.Command):
+class cmd_baz_import_branch(BzrToolsCommand):
     """Import an Arch or Baz branch into a bzr branch.
 
     WARNING: Encoding should not be specified unless necessary, because if you
@@ -625,8 +595,10 @@ class cmd_baz_import_branch(bzrlib.commands.Command):
     are incompatible.
     """
     takes_args = ['to_location', 'from_branch?', 'reuse_history*']
-    takes_options = ['verbose', Option('max-count', type=int),
-                     Option('encoding', type=str, 
+    takes_options = ['verbose', 
+                     Option('max-count', type=int, 
+                     help='Maximim revisions to import at once.'),
+                     Option('encoding', type=str,
                      help='Force encoding to specified value.  See WARNING.')]
 
     def run(self, to_location, from_branch=None, fast=False, max_count=None,
@@ -635,24 +607,24 @@ class cmd_baz_import_branch(bzrlib.commands.Command):
         from errors import NoPyBaz
         try:
             import baz_import
-            baz_import.baz_import_branch(to_location, from_branch, fast, 
+            baz_import.baz_import_branch(to_location, from_branch, fast,
                                          max_count, verbose, encoding, dry_run,
                                          reuse_history_list)
         except NoPyBaz:
             print "This command is disabled.  Please install PyBaz."
 
 
-class cmd_rspush(bzrlib.commands.Command):
+class cmd_rspush(BzrToolsCommand):
     """Upload this branch to another location using rsync.
 
-    If no location is specified, the last-used location will be used.  To 
-    prevent dirty trees from being uploaded, rspush will error out if there are 
-    unknown files or local changes.  It will also error out if the upstream 
-    directory is non-empty and not an earlier version of the branch. 
+    If no location is specified, the last-used location will be used.  To
+    prevent dirty trees from being uploaded, rspush will error out if there are
+    unknown files or local changes.  It will also error out if the upstream
+    directory is non-empty and not an earlier version of the branch.
     """
     takes_args = ['location?']
     takes_options = [Option('overwrite', help='Ignore differences between'
-                            ' branches and overwrite unconditionally'),
+                            ' branches and overwrite unconditionally.'),
                      Option('no-tree', help='Do not push the working tree,'
                             ' just the .bzr.')]
 
@@ -660,11 +632,11 @@ class cmd_rspush(bzrlib.commands.Command):
         from bzrlib import workingtree
         import bzrtools
         cur_branch = workingtree.WorkingTree.open_containing(".")[0]
-        bzrtools.rspush(cur_branch, location, overwrite=overwrite, 
+        bzrtools.rspush(cur_branch, location, overwrite=overwrite,
                       working_tree=not no_tree)
 
 
-class cmd_switch(bzrlib.commands.Command):
+class cmd_switch(BzrToolsCommand):
     """Set the branch of a lightweight checkout and update."""
 
     takes_args = ['to_location']
@@ -680,7 +652,7 @@ commands = [
             cmd_branches,
             cmd_branch_history,
             cmd_branch_mark,
-            cmd_cbranch,  
+            cmd_cbranch,
             cmd_cdiff,
             cmd_clean_tree,
             cmd_fetch_ghosts,
@@ -689,12 +661,12 @@ commands = [
             cmd_multi_pull,
             cmd_patch,
             cmd_rspush,
-            cmd_shelf, 
+            cmd_shelf,
             cmd_shell,
-            cmd_shelve, 
+            cmd_shelve,
             cmd_switch,
-            cmd_unshelve, 
-            cmd_zap,            
+            cmd_unshelve,
+            cmd_zap,
             ]
 
 
