@@ -63,8 +63,8 @@ class UncommittedCheckout(CommandError):
 class ParentMissingRevisions(CommandError):
     """The parent branch is missing revisions."""
     def __init__(self, parent):
-        CommandError.__init__(self, 
-            "The parent branch %s is missing revisions from this branch." % 
+        CommandError.__init__(self,
+            "The parent branch %s is missing revisions from this branch." %
             parent)
         self.parent = parent
 
@@ -72,3 +72,7 @@ class NoParent(CommandError):
     def __init__(self):
         CommandError.__init__(self, "There is no parent, so deleting the"
                                     " branch could destroy data.")
+
+class ChangedBinaryFiles(BzrError):
+
+    _fmt = 'Changes involve binary files.'
