@@ -1,7 +1,7 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 import os
 import re
-from subprocess import call
+from subprocess import call, PIPE
 import sys
 
 sys.path.insert(0, '..')
@@ -14,16 +14,7 @@ def minigrep(pattern, filename):
         match = re.search(pattern, line)
         if match is not None:
             return match
-match = minigrep('version="([^"]*)"', 'setup.py')
-if match is None:
-    print "No version line found"
-    sys.exit(1)
-if match.group(1) != bzrtools.__version__:
-    print "Mismatch between bzrtools version and setup.py version:\n %s %s"\
-        % (bzrtools.__version__, match.group(1))
-    sys.exit(1)
-    
-print "setup.py version: %s" % match.group(1)
+
 newsmatch = minigrep('RELEASE: bzrtools %s' % (bzrtools.__version__), 'NEWS')
 if newsmatch is None:
     print "NEWS entry missing"
@@ -37,7 +28,7 @@ if os.path.exists('../bzrtools.tar.gz'):
 if os.path.exists(final_name):
     print "Final file exists already."
     sys.exit(1)
-if call(['bzr', 'diff']) != 0:
+if call(['bzr', 'diff'], stdout=PIPE) != 0:
     print "Please commit before releasing"
     sys.exit(1)
 retcode = call(['bzr', 'export', '../bzrtools.tar.gz'])
@@ -47,6 +38,5 @@ os.rename('../bzrtools.tar.gz', final_name)
 print 'Created %s' % final_name
 call(['gpg', '--detach-sign', final_name])
 print 'Uploading...'
-call(['scp', final_name, final_name + '.sig', 
+call(['scp', final_name, final_name + '.sig',
       'panoramicfeedback.com:opensource/'])
-print "If you haven't committed, now would be a good time."
