@@ -7,6 +7,7 @@ from bzrlib.plugins.bzrtools.hunk_selector import (
     UnshelveHunkSelector,
     )
 from bzrlib.plugins.bzrtools.errors import NoColor
+from bzrlib.plugins.bzrtools import cmd_shelf
 
 
 class ShelfTests(bzrlib.tests.TestCaseWithTransport):
@@ -44,11 +45,11 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         finally:
             self.tree.unlock()
             old_tree.unlock()
-        keys = { 'filename' : filename , 'old_date': old_date, 
+        keys = { 'filename' : filename , 'old_date': old_date,
                  'new_date': new_date}
         hdr  = self.DIFF_HEADER % keys
         diff = diff % keys
-        self.assertEqual(self.capture('diff', retcode=1), hdr + diff + '\n')
+        self.assertEqual(self.run_bzr('diff', retcode=1)[0], hdr + diff + '\n')
 
     def _check_shelf(self, idx, diff=DIFF_1, filename='test_file',
                      new_date=None):
@@ -94,10 +95,10 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
                 self.tree.unlock()
 
             # Shelve the changes
-            self.run_bzr('shelve', '--all', retcode=0)
+            self.run_bzr('shelve --all', retcode=0)
 
             # Make sure there is no diff anymore
-            self.assertEqual(self.capture('diff', retcode=0), '')
+            self.assertEqual(self.run_bzr('diff', retcode=0)[0], '')
 
             # Make sure the file is actually back the way it was
             self.assertEqual(file('test_file').read(), self.ORIGINAL)
@@ -105,7 +106,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
             self._check_shelf('00', new_date=new_date)
 
             # Unshelve
-            self.run_bzr('unshelve', '--all', retcode=0)
+            self.run_bzr('unshelve --all', retcode=0)
 
             self._check_diff()
 
@@ -121,7 +122,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.__create_and_add_test_file()
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', retcode=3)
+        self.run_bzr('shelve --all', retcode=3)
 
         if os.path.exists(os.path.join(self.tree.branch.base,
                 '.shelf/shelves/default/00')):
@@ -145,7 +146,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.tree.commit(message='update test_file')
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', '-r', '1', retcode=0)
+        self.run_bzr('shelve --all -r 1', retcode=0)
 
         self._check_diff(self.DIFF_2)
 
@@ -153,7 +154,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertEqual(file('test_file').read(), self.ORIGINAL)
 
         # Unshelve
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
 
         # Make sure the file is back the way it should be
         self.assertEqual(file('test_file').read(), self.MODIFIED)
@@ -161,8 +162,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
     def test_shelf_with_two_revisions(self):
         self.tree = self.make_branch_and_tree('.')
 
-        cmd = 'shelve --all -r 1..2'
-        (stdout, stderr) = self.run_bzr_captured(cmd.split(), retcode=None)
+        stdout, stderr = self.run_bzr('shelve --all -r 1..2', retcode=None)
 
         self.assertEqual(stderr.split('\n')[0],
             'bzr: ERROR: shelve only accepts a single revision parameter.')
@@ -177,10 +177,10 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.build_tree_contents([('test_file', 'patch %s\n' % patch)])
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', retcode=0)
+        self.run_bzr('shelve --all', retcode=0)
 
         # Make sure there is no diff anymore
-        self.assertEqual(self.capture('diff', retcode=0), '')
+        self.assertEqual(self.run_bzr('diff', retcode=0)[0], '')
 
         # Check the shelf is right
         shelf = open(os.path.join(self.tree.basedir,
@@ -188,7 +188,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertTrue('patch %s' % patch in shelf)
 
         # Check the shown output is right
-        shown = self.capture('shelf show %s' % patch, retcode=0)
+        shown = self.run_bzr('shelf show %s' % patch, retcode=0)[0]
         self.assertEqual(shown, shelf)
 
     def test_shelf_show_multi(self):
@@ -204,7 +204,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertTrue('patch 00' in shelf)
 
         # Check the shown output is right
-        shown = self.capture('shelf show 00', retcode=0)
+        shown = self.run_bzr('shelf show 00', retcode=0)[0]
         self.assertEqual(shown, shelf)
 
     def test_shelf_show_unspecified(self):
@@ -220,12 +220,12 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertTrue('patch 02' in shelf)
 
         # Check the shown output is right
-        shown = self.capture('shelf show', retcode=0)
+        shown = self.run_bzr('shelf show', retcode=0)[0]
         self.assertEqual(shown, shelf)
 
     def test_shelf_show_with_no_patch(self):
         self.tree = self.make_branch_and_tree('.')
-        stderr = self.run_bzr_captured(['shelf', 'show', '00'], retcode=None)[1]
+        stderr = self.run_bzr('shelf show 00', retcode=None)[1]
         self.assertTrue("Patch '00' doesn't exist on shelf default!" in stderr)
 
     def test_shelf_unshelve_failure(self):
@@ -237,7 +237,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         file('test_file', 'w').write(self.MODIFIED)
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', retcode=0)
+        self.run_bzr('shelve --all', retcode=0)
 
         # Write an unapplyable patch into the shelf
         shelf = open(os.path.join(self.tree.basedir,
@@ -246,7 +246,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         shelf.close()
 
         # Unshelve, should fail
-        self.run_bzr('unshelve', '--all', retcode=3)
+        self.run_bzr('unshelve --all', retcode=3)
 
         # Make sure the patch is still there, eventhough it's broken
         shelf = open(os.path.join(self.tree.basedir,
@@ -254,7 +254,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertEqual(shelf, self.DIFF_2)
 
         # Working tree should be unchanged
-        diff = self.capture('diff', retcode=0)
+        diff = self.run_bzr('diff', retcode=0)[0]
         self.assertEqual(diff, '')
 
     def test_shelf_unshelve_failure_two_hunks(self):
@@ -268,21 +268,21 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         file('test_file2', 'w').write(self.MODIFIED)
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', retcode=0)
+        self.run_bzr('shelve --all', retcode=0)
 
         # Put the changes to test_file back, the shelved patch won't apply now
         file('test_file', 'w').write(self.MODIFIED)
         self.tree.commit(message='screw up test_file')
 
         # Unshelve, should fail
-        self.run_bzr('unshelve', '--all', retcode=3)
+        self.run_bzr('unshelve --all', retcode=3)
 
         # Working tree should be unchanged
-        diff = self.capture('diff', retcode=0)
+        diff = self.run_bzr('diff', retcode=0)[0]
         self.assertEqual(diff, '')
 
         # Force should succeed and modify test_file2, but leave shelf
-        self.run_bzr('unshelve', '--force', '--all', retcode=0)
+        self.run_bzr('unshelve --force --all', retcode=0)
         self.assertEqual(open('test_file2').read(), self.MODIFIED)
         self.assertTrue(os.path.exists('.shelf/shelves/default/00'))
 
@@ -297,23 +297,23 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         file('test_file2', 'w').write(self.MODIFIED)
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
-        self.run_bzr('shelve', '--all', 'test_file2', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
+        self.run_bzr('shelve --all test_file2', retcode=0)
 
         # Unshelve
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
 
         # We should now have 00 and 01~
         self.assertTrue(os.path.exists('.shelf/shelves/default/00'))
         self.assertTrue(os.path.exists('.shelf/shelves/default/01~'))
 
         # Check ls works
-        lines = self.capture('shelf ls', retcode=0).split('\n')
+        lines = self.run_bzr('shelf ls', retcode=0)[0].split('\n')
         for line in lines:
             self.assertFalse(line.startswith(' 01'))
 
         # Unshelve, if unshelve is confused by the backup it will fail
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
 
     def test_shelf_delete(self):
         self.tree = self.make_branch_and_tree('.')
@@ -336,13 +336,13 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
             self.tree.unlock()
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
-        self.run_bzr('shelve', '--all', 'test_file2', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
+        self.run_bzr('shelve --all test_file2', retcode=0)
 
         self._check_shelf('00', new_date=new_date)
 
         # Delete 00
-        self.run_bzr('shelf', 'delete', '00', retcode=0)
+        self.run_bzr('shelf delete 00', retcode=0)
 
         # We should now have 01 but not 00, but we should have 00~
         self.assertFalse(os.path.exists('.shelf/shelves/default/00'))
@@ -353,28 +353,28 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self._check_shelf('00~', new_date=new_date)
 
         # Check ls works
-        lines = self.capture('shelf ls', retcode=0).split('\n')
+        lines = self.run_bzr('shelf ls', retcode=0)[0].split('\n')
         for line in lines:
             self.assertFalse(line.startswith(' 00'))
 
         # Unshelve should unshelve 01
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
         self.assertEqual(file('test_file2').read(), self.MODIFIED)
 
     def test_shelf_gaps(self):
         self.tree = self.make_branch_and_tree('.')
         self.__create_and_add_test_file()
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
 
         # Now delete 00, leaving 01, next shelve should go into 02
-        self.run_bzr('shelf', 'delete', '0', retcode=0)
+        self.run_bzr('shelf delete 0', retcode=0)
         self.assertFalse(os.path.exists('.shelf/shelves/default/00'))
         self.assertFalse(os.path.exists('.shelf/shelves/default/02'))
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
         self.assertFalse(os.path.exists('.shelf/shelves/default/00'))
         self.assertTrue(os.path.exists('.shelf/shelves/default/02'))
 
@@ -385,7 +385,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
 
         # Modify then shelve, so we're not upgrading to 00, just for kicks
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
 
         open('.bzr-shelf', 'w').write('First old shelf')
         open('.bzr-shelf-1', 'w').write('Second old shelf')
@@ -393,14 +393,14 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
 
         # shelve and unshelve should bitch and do nothing
         file('test_file', 'w').write('blah blah blah')
-        self.run_bzr('shelve', '--all', retcode=3)
+        self.run_bzr('shelve --all', retcode=3)
         self.assertFalse(os.path.exists('.shelf/shelves/default/01'))
         self.assertEqual(file('test_file').read(), 'blah blah blah')
-        self.run_bzr('unshelve', '--all', retcode=3)
+        self.run_bzr('unshelve --all', retcode=3)
         self.assertTrue(os.path.exists('.shelf/shelves/default/00'))
 
         # Upgrade, make sure it worked
-        self.run_bzr('shelf', 'upgrade', retcode=0)
+        self.run_bzr('shelf upgrade', retcode=0)
         self.assertEqual(open('.shelf/shelves/default/01').read(),
                 'First old shelf')
         self.assertEqual(open('.shelf/shelves/default/02').read(),
@@ -417,7 +417,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertFalse(os.path.exists('.bzr-shelf-3'))
 
         # Shelve should work now
-        self.run_bzr('shelve', '--all', retcode=0)
+        self.run_bzr('shelve --all', retcode=0)
 
     def test_shelf_p1_patch(self):
         self.tree = self.make_branch_and_tree('.')
@@ -425,7 +425,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.__create_and_add_test_file()
 
         # Run a benign shelf command to setup .shelf for us
-        self.run_bzr('shelf', 'ls', retcode=0)
+        self.run_bzr('shelf ls', retcode=0)
 
         old_tree = self.tree.basis_tree()
         old_tree.lock_read()
@@ -447,7 +447,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         open('.shelf/shelves/default/00', 'w').write(diff)
 
         # This should work
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
 
         self._check_diff()
 
@@ -468,23 +468,23 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         f.close()
 
         # Shelve the changes
-        self.run_bzr('shelve', '--all', retcode=0)
+        self.run_bzr('shelve --all', retcode=0)
 
         # Working tree should be unchanged
-        diff = self.capture('diff', retcode=0)
+        diff = self.run_bzr('diff', retcode=0)[0]
         self.assertEqual(diff, '')
 
         # Unshelve, should succeed
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
 
         self._check_diff(filename='subdir/test_file')
 
         # Make sure relative filenames work ok
-        self.run_bzr('shelve', 'test_file', '--all', retcode=0)
+        self.run_bzr('shelve test_file --all', retcode=0)
 
     def test_shelf_shelf_bogus_subcommand(self):
         self.tree = self.make_branch_and_tree('.')
-        self.run_bzr('shelf', 'foo', retcode=3) # <- retcode == 3
+        self.run_bzr('shelf foo', retcode=3) # <- retcode == 3
 
     def test_shelf_OOO_unshelve(self):
         self.tree = self.make_branch_and_tree('.')
@@ -498,7 +498,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
 
         # Shelve the changes
         for i in range(1, 5):
-            self.run_bzr('shelve', '--all', 'test_file%d' % i, retcode=0)
+            self.run_bzr(['shelve', '--all', 'test_file%d' % i], retcode=0)
 
         # Check shelving worked
         for i in range(1, 5):
@@ -509,31 +509,31 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
             self.assertTrue(os.path.exists('.shelf/shelves/default/0%d' % i))
 
         # Unshelve 00
-        self.run_bzr('unshelve', '--all', '00', retcode=0)
+        self.run_bzr('unshelve --all 00', retcode=0)
         self.assertEqual(file('test_file1').read(), self.MODIFIED)
 
         # Check ls works
-        lines = self.capture('shelf ls', retcode=0).split('\n')
+        lines = self.run_bzr('shelf ls', retcode=0)[0].split('\n')
         for line in lines:
             self.assertFalse(line.startswith(' 00'))
 
         # Check we can reshelve once we've unshelved out of order, should be 04
         self.assertFalse(os.path.exists('.shelf/shelves/default/04'))
-        self.run_bzr('shelve', '--all')
+        self.run_bzr('shelve --all')
         self.assertTrue(os.path.exists('.shelf/shelves/default/04'))
 
         # Check ls works
-        text = self.capture('shelf ls', retcode=0)
+        text = self.run_bzr('shelf ls', retcode=0)[0]
         for line in text.split('\n'):
             self.assertFalse(line.startswith(' 00'))
 
         # We now have 01,02,03,04
         # Unshelve 02
-        self.run_bzr('unshelve', '--all', '02', retcode=0)
+        self.run_bzr('unshelve --all 02', retcode=0)
         self.assertEqual(file('test_file3').read(), self.MODIFIED)
 
         # Unshelve the default, this is the reshelved 00, hence modifies file 1
-        self.run_bzr('unshelve', '--all', retcode=0)
+        self.run_bzr('unshelve --all', retcode=0)
         self.assertEqual(file('test_file1').read(), self.MODIFIED)
 
     def test_shelf_switch_basic(self):
@@ -542,12 +542,12 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
 
         # This should go to "default"
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
 
         # Switch to "other"
-        self.run_bzr('shelf', 'switch', 'other', retcode=0)
+        self.run_bzr('shelf switch other', retcode=0)
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
 
         # Check it worked
         self.assertTrue(os.path.exists('.shelf/shelves/default/00'))
@@ -555,26 +555,32 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         self.assertTrue(os.path.exists('.shelf/shelves/other/00'))
 
         # Switch back
-        self.run_bzr('shelf', 'switch', 'default', retcode=0)
+        self.run_bzr('shelf switch default', retcode=0)
         file('test_file', 'w').write(self.MODIFIED)
-        self.run_bzr('shelve', '--all', 'test_file', retcode=0)
+        self.run_bzr('shelve --all test_file', retcode=0)
 
         # Check that worked
         self.assertTrue(os.path.exists('.shelf/shelves/default/01'))
         self.assertFalse(os.path.exists('.shelf/shelves/other/01'))
 
+    def test_shelf_binary(self):
+        self.tree = self.make_branch_and_tree('.')
+        self.build_tree_contents([('file', '\x00')])
+        self.tree.add('file')
+        self.run_bzr_error(['Changes involve binary files.'], 'shelve --all')
+
     def test_shelf_bad_patch_arg(self):
         self.tree = self.make_branch_and_tree('.')
 
         # Check the bad arg handling
-        stdout, error = self.run_bzr_captured(['unshelve', '01'], retcode=3)
+        stdout, error = self.run_bzr('unshelve 01', retcode=3)
         self.assertTrue("Patch '01' doesn't exist on shelf" in error)
 
-        stdout, error = self.run_bzr_captured(['unshelve', 'foo'], retcode=3)
+        stdout, error = self.run_bzr('unshelve foo', retcode=3)
         self.assertTrue("Invalid patch name 'foo'" in error)
 
         # Hex and is cracky, so it shouldn't work
-        stdout, error = self.run_bzr_captured(['unshelve', '0x00'], retcode=3)
+        stdout, error = self.run_bzr(['unshelve', '0x00'], retcode=3)
         self.assertTrue("Invalid patch name '0x00'" in error)
 
     def test_color_hunk_selector(self):
@@ -612,7 +618,9 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
         f = file('test_file', 'wb')
         f.write(self.MODIFIED)
         f.close()
-        stdout, error = self.run_bzr_captured(['shelve', '--all', 
-                                               '--no-color'])
-        stdout, error = self.run_bzr_captured(['unshelve', '--all', 
-                                               '--no-color'])
+        stdout, error = self.run_bzr('shelve --all --no-color')
+        stdout, error = self.run_bzr('unshelve --all --no-color')
+
+    def test_shelf_help(self):
+        self.assertContainsRe(cmd_shelf().help(),
+                              'list\n.*List the patches on the current shelf')
