@@ -23,8 +23,8 @@ try:
 except ImportError:
     pybaz = None
 import os
-from bzrlib.plugins.bzrtools import cmd_baz_import 
-from bzrlib.plugins.bzrtools.baz_import import (import_version, 
+from bzrlib.plugins.bzrtools import cmd_baz_import
+from bzrlib.plugins.bzrtools.baz_import import (import_version,
                                                 revision_id,
                                                 make_archive,
                                                 map_file_id)
@@ -33,7 +33,7 @@ from StringIO import StringIO
 import tempfile
 from testresources import (TestResource, TestLoader, OptimisingTestSuite,
                                ResourcedTestCase)
-    
+
 import bzrlib
 from bzrlib.errors import NoSuchRevision
 from bzrlib.plugins.bzrtools.fai import namespace_previous
@@ -44,7 +44,7 @@ def test_suite():
         from unittest import TestSuite
         return TestSuite()
     return TestLoader().loadTestsFromName(__name__)
- 
+
 
 class BazTreeResource(TestResource):
 
@@ -72,9 +72,9 @@ class BazTreeResource(TestResource):
             pybaz.Version(self._empty_tag))
 
         self._empty_merged_tag = 'demo@DONOTUSE/c--empty-merged-tag--0'
-        self._empty_merged_tag_bzr_base = revision_id(self._empty_merged_tag 
+        self._empty_merged_tag_bzr_base = revision_id(self._empty_merged_tag
                                                  + '--base-0', None)
-        self._empty_merged_tag_bzr = revision_id(self._empty_merged_tag 
+        self._empty_merged_tag_bzr = revision_id(self._empty_merged_tag
                                                  + '--patch-1', None)
         pybaz.Revision('demo@DONOTUSE/c--import--0--base-0').make_continuation(
             pybaz.Version(self._empty_merged_tag))
@@ -86,7 +86,7 @@ class BazTreeResource(TestResource):
         msg["summary"]="did a merge, yarh"
         tree.commit(msg)
         shutil.rmtree(os.path.join(self._tmpdir, 'tree'))
-        
+
         # tree, two commits, includes merge of other branch
         self._empty_merged_tag_2 = 'demo@DONOTUSE/c--empty-tag-2--0'
         self._empty_merged_tag_2_bzr_base = revision_id(
@@ -114,7 +114,7 @@ class BazTreeResource(TestResource):
         tree = pybaz.Revision(self._bad_id_tag + '--base-0').get(
             os.path.join(self._tmpdir, 'tree'))
         from bzrlib.plugins.bzrtools.baz_import import add_file
-        add_file(os.path.join(self._tmpdir,'tree/path'), 'text', 
+        add_file(os.path.join(self._tmpdir,'tree/path'), 'text',
                  'this_id/needs%escaping')
         msg = tree.log_message()
         msg["summary"] = "commit something which needs escaping."
@@ -153,7 +153,7 @@ class BazTreeResource(TestResource):
     def make_empty_import(self):
         self._import = 'demo@DONOTUSE/c--import--0'
         os.mkdir(os.path.join(self._tmpdir, 'tree'))
-        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'), 
+        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'),
                                self._import)
         msg = tree.log_message()
         msg["summary"] = "I am importing now"
@@ -163,7 +163,7 @@ class BazTreeResource(TestResource):
     def make_utf8_log(self):
         self._utf8 = 'demo@DONOTUSE/c--utf8--0'
         os.mkdir(os.path.join(self._tmpdir, 'tree'))
-        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'), 
+        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'),
                                self._utf8)
         msg = tree.log_message()
         msg["summary"] = u"I am importing now\u1234".encode('utf-8')
@@ -175,13 +175,13 @@ class BazTreeResource(TestResource):
         self._archive = make_archive('demo-gone@DONOTUSE',
                                      str(self._archivegoneroot))
         self._missing_import = 'demo-gone@DONOTUSE/c--import--0'
-        self._missing_import_bzr = revision_id(self._missing_import 
+        self._missing_import_bzr = revision_id(self._missing_import
                                                  + '--base-0', None)
         self._missing_ancestor = 'demo@DONOTUSE/c--gone--0'
-        self._missing_ancestor_bzr = revision_id(self._missing_ancestor 
+        self._missing_ancestor_bzr = revision_id(self._missing_ancestor
                                                  + '--base-0', None)
         os.mkdir(os.path.join(self._tmpdir, 'tree'))
-        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'), 
+        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'),
                                self._missing_import)
         msg = tree.log_message()
         msg["summary"] = "I am importing now"
@@ -193,11 +193,11 @@ class BazTreeResource(TestResource):
 
         # make an import for testing history-reuse logic.
         # note the use of a namespace layout here.
-        self._missing_import_imported = os.path.join(self._tmpdir, 
+        self._missing_import_imported = os.path.join(self._tmpdir,
                                                      'archivegone-bzr')
         os.mkdir(os.path.join(self._tmpdir, 'archivegone-bzr'))
         os.mkdir(os.path.join(self._tmpdir, 'archivegone-bzr', 'c'))
-        import_version(os.path.join(self._tmpdir, 'archivegone-bzr', 
+        import_version(os.path.join(self._tmpdir, 'archivegone-bzr',
                                     'c', 'import'),
                        pybaz.Version(self._missing_import), None)
         # and make it inaccessible
@@ -206,7 +206,7 @@ class BazTreeResource(TestResource):
     def make_inbranch_continuation(self):
         self._inbranch_tag = 'demo@DONOTUSE/c--inbranch-tag--0'
         self._inbranch_tag_base = self._inbranch_tag + '--base-0'
-        self._inbranch_tag_base_bzr = revision_id(self._inbranch_tag_base, 
+        self._inbranch_tag_base_bzr = revision_id(self._inbranch_tag_base,
                                                   None)
         pybaz.Revision('demo@DONOTUSE/c--import--0--base-0').make_continuation(
             pybaz.Version(self._inbranch_tag))
@@ -255,7 +255,7 @@ class TestImportBranch(TestCaseInTempDir):
     def test_import_empty(self):
         import_version('output', pybaz.Version(self._baz._import), None)
         # expected results:
-        # one commit, no files, revision identifier of 
+        # one commit, no files, revision identifier of
         # 'demo@DONOTUSE_c--import--0--base-0'
         branch = Branch.open('output')
         repo = branch.repository
@@ -281,7 +281,7 @@ class TestImportBranch(TestCaseInTempDir):
     def test_empty_tagged(self):
         import_version('output', pybaz.Version(self._baz._empty_tag), None)
         # expected results:
-        # two commits, no files, revision identifiers of 
+        # two commits, no files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' and
         # self._baz._empty_tag_bzr
         branch = Branch.open('output')
@@ -299,15 +299,15 @@ class TestImportBranch(TestCaseInTempDir):
 
         # and we should get some expected values:
         self.assertEqual(rev.committer, "Test User<test@example.org>")
-        self.assertEqual(rev.message, 
+        self.assertEqual(rev.message,
                          "tag of demo@DONOTUSE/c--import--0--base-0")
         self.assertEqual(rev.revision_id, self._baz._empty_tag_bzr)
 
     def test_empty_merged_tagged(self):
-        import_version('output', pybaz.Version(self._baz._empty_merged_tag), 
+        import_version('output', pybaz.Version(self._baz._empty_merged_tag),
                        None)
         # expected results:
-        # two commits, no files, revision identifiers of 
+        # two commits, no files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' and
         # self._baz._empty_merged_tag_bzr_base
         # self._baz._empty_merged_tag_bzr
@@ -320,16 +320,16 @@ class TestImportBranch(TestCaseInTempDir):
                           self._baz._empty_merged_tag_bzr_base,
                           self._baz._empty_merged_tag_bzr])
         # and again.
-        import_version('output2', pybaz.Version(self._baz._empty_merged_tag), 
+        import_version('output2', pybaz.Version(self._baz._empty_merged_tag),
                        None)
         branch2 = Branch.open('output2')
         repo2 = branch2.repository
         # and import what we should be merged up against for checking with.
         import_version('output3', pybaz.Version(self._baz._empty_tag), None)
         branch3 = Branch.open('output3')
-        
+
         self.assertEqual(branch.revision_history(), branch2.revision_history())
-        self.assertNotEqual(branch.revision_history(), 
+        self.assertNotEqual(branch.revision_history(),
                             branch3.revision_history())
         # check revisions in the history.
         rev = repo.get_revision(self._baz._empty_merged_tag_bzr_base)
@@ -338,7 +338,7 @@ class TestImportBranch(TestCaseInTempDir):
         self.assertEqual(rev, rev2)
         # and we should get some expected values:
         self.assertEqual(rev.committer, "Test User<test@example.org>")
-        self.assertEqual(rev.message, 
+        self.assertEqual(rev.message,
                          "tag of demo@DONOTUSE/c--import--0--base-0")
         self.assertEqual(rev.revision_id, self._baz._empty_merged_tag_bzr_base)
         self.assertEqual(['Arch-1:demo@DONOTUSE%c--import--0--base-0'],
@@ -357,15 +357,15 @@ class TestImportBranch(TestCaseInTempDir):
                          self._baz._empty_merged_tag_bzr_base)
         self.assertEqual(rev.parent_ids[1], self._baz._empty_tag_bzr)
 
-        # this tree should have nothing missing from that tree.   
+        # this tree should have nothing missing from that tree.
         # FIXME there is no code for this right now.
         # self.assertEqual(branch.missing_revisions(branch3), [])
-        
+
     def test_merge_branch_with_merges(self):
-        import_version('output', pybaz.Version(self._baz._empty_merged_tag_2), 
+        import_version('output', pybaz.Version(self._baz._empty_merged_tag_2),
                        None)
         # expected results:
-        # two commits, no files, revision identifiers of 
+        # two commits, no files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' and
         # self._baz._empty_merged_tag_2_bzr_base
         # self._baz._empty_merged_tag_2_bzr
@@ -386,9 +386,9 @@ class TestImportBranch(TestCaseInTempDir):
         import_version('output3', pybaz.Version(self._baz._empty_merged_tag),
                        None)
         branch3 = Branch.open('output3')
-        
+
         self.assertEqual(branch.revision_history(), branch2.revision_history())
-        self.assertNotEqual(branch.revision_history(), 
+        self.assertNotEqual(branch.revision_history(),
                             branch3.revision_history())
         # check revisions in the history.
         rev = repo.get_revision(self._baz._empty_merged_tag_2_bzr_base)
@@ -397,9 +397,9 @@ class TestImportBranch(TestCaseInTempDir):
         self.assertEqual(rev, rev2)
         # and we should get some expected values:
         self.assertEqual(rev.committer, "Test User<test@example.org>")
-        self.assertEqual(rev.message, 
+        self.assertEqual(rev.message,
                          "tag of demo@DONOTUSE/c--import--0--base-0")
-        self.assertEqual(rev.revision_id, 
+        self.assertEqual(rev.revision_id,
                          self._baz._empty_merged_tag_2_bzr_base)
 
         # check next revisions in the history.
@@ -416,15 +416,15 @@ class TestImportBranch(TestCaseInTempDir):
         self.assertEqual(rev.parent_ids[1],
                          self._baz._empty_merged_tag_bzr)
 
-        # this tree should have nothing missing from that tree.   
+        # this tree should have nothing missing from that tree.
         # FIXME there is no code for this right now.
         # self.assertEqual(branch.missing_revisions(branch3), [])
-        
+
     def test_import_symlink(self):
-        import_version('output', pybaz.Version(self._baz._import_symlink), 
+        import_version('output', pybaz.Version(self._baz._import_symlink),
                        None, max_count=1)
         # expected results:
-        # two commits, no files, revision identifier of 
+        # two commits, no files, revision identifier of
         # 'demo@DONOTUSE_c--import--0--base-0'
         branch = Branch.open('output')
         self.assertEqual(branch.revision_history(),
@@ -459,7 +459,7 @@ class TestImportBranch(TestCaseInTempDir):
         import_version('output', pybaz.Version(self._baz._missing_ancestor),
                        None)
         # expected results:
-        # one commits, no files, revision identifiers of 
+        # one commits, no files, revision identifiers of
         # 'demo@DONOTUSE_c--gone--0--base-0' and
         # a merge of demo-gone@DONOTUSE%c--import--0
         branch = Branch.open('output')
@@ -467,7 +467,7 @@ class TestImportBranch(TestCaseInTempDir):
                          [self._baz._missing_ancestor_bzr])
         rev = branch.repository.get_revision(self._baz._missing_ancestor_bzr)
         # and again.
-        import_version('output2', pybaz.Version(self._baz._missing_ancestor), 
+        import_version('output2', pybaz.Version(self._baz._missing_ancestor),
                        None)
         branch2 = Branch.open('output2')
         self.assertEqual(branch.revision_history(), branch2.revision_history())
@@ -477,14 +477,14 @@ class TestImportBranch(TestCaseInTempDir):
 
         # and we should get some expected values:
         self.assertEqual(rev.committer, "Test User<test@example.org>")
-        self.assertEqual(rev.message, 
+        self.assertEqual(rev.message,
                          "tag of demo-gone@DONOTUSE/c--import--0--base-0")
         self.assertEqual(rev.revision_id, self._baz._missing_ancestor_bzr)
         self.assertEqual(rev.parent_ids[0], self._baz._missing_import_bzr)
         self.assertEqual(1, len(rev.parent_ids))
 
         # must NOT be able to get the merged evision
-        self.assertRaises(NoSuchRevision, branch.repository.get_revision, 
+        self.assertRaises(NoSuchRevision, branch.repository.get_revision,
                           self._baz._missing_import_bzr)
 
     def test_missing_ancestor_reusing_history(self):
@@ -492,8 +492,8 @@ class TestImportBranch(TestCaseInTempDir):
                        None,
                        reuse_history_from=[self._baz._missing_import_imported])
         # expected results:
-        # one commits, no files, revision identifiers of 
-        # 'demo-gone@DONOTUSE%c--import--0--base-0' and 
+        # one commits, no files, revision identifiers of
+        # 'demo-gone@DONOTUSE%c--import--0--base-0' and
         # 'demo@DONOTUSE%c--gone--0--base-0'
         branch = Branch.open('output')
         self.assertEqual(branch.revision_history(),
@@ -515,7 +515,7 @@ class TestImportBranch(TestCaseInTempDir):
 
         # and we should get some expected values:
         self.assertEqual(rev.committer, "Test User<test@example.org>")
-        self.assertEqual(rev.message, 
+        self.assertEqual(rev.message,
                          "tag of demo-gone@DONOTUSE/c--import--0--base-0")
         self.assertEqual(rev.revision_id, self._baz._missing_ancestor_bzr)
         self.assertEqual(rev.parent_ids[0], self._baz._missing_import_bzr)
@@ -524,7 +524,7 @@ class TestImportBranch(TestCaseInTempDir):
     def test_bad_file_id(self):
         import_version('output', pybaz.Version(self._baz._bad_id_tag), None)
         # expected results:
-        # three commits, one files, revision identifiers of 
+        # three commits, one files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' ,
         # 'demo@DONOTUSE/c--bad-id--0--base-0' ,
         # ''demo@DONOTUSE/c--bad-id--0--patch-1'
@@ -542,7 +542,7 @@ class TestImportBranch(TestCaseInTempDir):
         import_version('output', pybaz.Version(self._baz._bad_id_tag), None,
                        max_count=2)
         # expected results:
-        # three commits, one files, revision identifiers of 
+        # three commits, one files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' ,
         # 'demo@DONOTUSE/c--bad-id--0--base-0' ,
         # ''demo@DONOTUSE/c--bad-id--0--patch-1'
@@ -571,7 +571,7 @@ class TestImportBranch(TestCaseInTempDir):
     def test_appending_revisions_all_already_present(self):
         import_version('output', pybaz.Version(self._baz._bad_id_tag), None)
         # expected results:
-        # three commits, one files, revision identifiers of 
+        # three commits, one files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' ,
         # 'demo@DONOTUSE/c--bad-id--0--base-0' ,
         # ''demo@DONOTUSE/c--bad-id--0--patch-1'
@@ -601,7 +601,7 @@ class TestImportBranch(TestCaseInTempDir):
     def test_inbranch_conversion(self):
         import_version('output', pybaz.Version(self._baz._inbranch_tag), None)
         # expected results:
-        # three commits, no files, revision identifiers of 
+        # three commits, no files, revision identifiers of
         # 'demo@DONOTUSE_c--import--0--base-0' and
         # self._baz._inbranch_tag_base_bzr
         # self._baz._inbranch_tag_head_bzr
@@ -614,7 +614,7 @@ class TestImportBranch(TestCaseInTempDir):
         # and again.
         import_version('output2', pybaz.Version(self._baz._inbranch_tag), None)
         branch2 = Branch.open('output2')
-        
+
         self.assertEqual(branch.revision_history(), branch2.revision_history())
         # check revisions in the history.
         rev = branch.repository.get_revision(self._baz._inbranch_tag_base_bzr)
@@ -644,7 +644,7 @@ class TestImportBranch(TestCaseInTempDir):
         branch = bzrlib.bzrdir.BzrDir.create_branch_convenience(path)
         import_version(path, pybaz.Version(self._baz._import), None)
         # expected results:
-        # one commit, revision identifier of 
+        # one commit, revision identifier of
         # 'demo@DONOTUSE_c--import--0--base-0'
         self.assertEqual(branch.revision_history(),
                          ['Arch-1:demo@DONOTUSE%c--import--0--base-0'])
@@ -662,11 +662,11 @@ class TestNamespacePrevious(TestCase):
     def test_patch1_base0(self):
         self.assertEqual(namespace_previous(self.version['patch-1']),
                          self.version['base-0'])
-        
+
     def test_patch3000_patch2999(self):
         self.assertEqual(namespace_previous(self.version['patch-3000']),
                          self.version['patch-2999'])
-        
+
     def test_version0_raises(self):
         self.assertRaises(RuntimeError, namespace_previous,
                           self.version['version-0'])
@@ -693,7 +693,7 @@ class TestNamespaceMapping(TestCase):
         from bzrlib.plugins.bzrtools.baz_import import map_namespace
         category = pybaz.Category('foo@example.com/c')
         self.assertRaises(pybaz.errors.NamespaceError, map_namespace, category)
-        self.assertEqual('c/+trunk', 
+        self.assertEqual('c/+trunk',
                          map_namespace(pybaz.Version("%s--0" % category)))
         self.assertEqual('c/0.1/+trunk',
                          map_namespace(pybaz.Version('%s--0.1' % category)))
@@ -726,7 +726,7 @@ class TestImport(TestCaseInTempDir):
     def make_import(self, namespace):
         self._import = 'demo@DONOTUSE/%s' % namespace
         os.mkdir(os.path.join(self._tmpdir, 'tree'))
-        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'), 
+        tree = pybaz.init_tree(os.path.join(self._tmpdir, 'tree'),
                                self._import)
         msg = tree.log_message()
         msg["summary"] = "I am importing now"
@@ -749,9 +749,9 @@ class TestImport(TestCaseInTempDir):
         command = cmd_baz_import()
         command.run(os.path.join(self._tmpdir, 'output'), 'demo@DONOTUSE')
         self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output')))
-        self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output', 
+        self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output',
                                        'c','+trunk')))
-        self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output', 
+        self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output',
                                                     'c1', '0.2','branch')))
         default_format = repository.RepositoryFormat.get_default_format()
         if getattr(default_format, 'rich_root_data', False):
@@ -766,41 +766,41 @@ class TestImport(TestCaseInTempDir):
         command = cmd_baz_import()
         command.run(os.path.join(self._tmpdir, 'output'), 'demo@DONOTUSE')
         command.run(os.path.join(self._tmpdir, 'output'), 'demo@DONOTUSE')
-        
+
     def test_accepts_reuse_history(self):
         self.make_import('c--0')
-        self.run_bzr('baz-import', os.path.join(self._tmpdir, 'output'),
-                     'demo@DONOTUSE', '.', '.')
-        
-    def test_does_not_need_reuse_history(self):
-        self.make_import('c--0')
-        self.run_bzr('baz-import', os.path.join(self._tmpdir, 'output'),
-                     'demo@DONOTUSE')
+        self.run_bzr(['baz-import', os.path.join(self._tmpdir, 'output'),
+                      'demo@DONOTUSE', '.', '.'])
 
     def test_does_not_need_reuse_history(self):
         self.make_import('c--0')
-        self.run_bzr('baz-import', os.path.join(self._tmpdir, 'output'),
-                     'demo@DONOTUSE')
+        self.run_bzr(['baz-import', os.path.join(self._tmpdir, 'output'),
+                      'demo@DONOTUSE'])
+
+    def test_does_not_need_reuse_history(self):
+        self.make_import('c--0')
+        self.run_bzr(['baz-import', os.path.join(self._tmpdir, 'output'),
+                      'demo@DONOTUSE'])
 
     def test_encoding_flag(self):
         self.make_import('c--0')
-        self.run_bzr('baz-import', os.path.join(self._tmpdir, 'output'),
-                     'demo@DONOTUSE')
-        self.assertEqual(['Arch-1:demo@DONOTUSE%c--0--base-0'], 
-                         Branch.open(os.path.join(self._tmpdir, 
+        self.run_bzr(['baz-import', os.path.join(self._tmpdir, 'output'),
+                      'demo@DONOTUSE'])
+        self.assertEqual(['Arch-1:demo@DONOTUSE%c--0--base-0'],
+                         Branch.open(os.path.join(self._tmpdir,
                                      'output/c/+trunk')).revision_history())
-        self.run_bzr('baz-import', os.path.join(self._tmpdir, 'output2'),
-                     'demo@DONOTUSE', '--encoding', 'utf-8')
-        self.assertEqual(['Arch-1-utf-8:demo@DONOTUSE%c--0--base-0'], 
-                         Branch.open(os.path.join(self._tmpdir, 
+        self.run_bzr(['baz-import', os.path.join(self._tmpdir, 'output2'),
+                      'demo@DONOTUSE', '--encoding', 'utf-8'])
+        self.assertEqual(['Arch-1-utf-8:demo@DONOTUSE%c--0--base-0'],
+                         Branch.open(os.path.join(self._tmpdir,
                                      'output2/c/+trunk')).revision_history())
-        self.run_bzr('baz-import-branch', os.path.join(self._tmpdir, 'output3'),
-                     'demo@DONOTUSE/c--0')
-        self.assertEqual(['Arch-1:demo@DONOTUSE%c--0--base-0'], 
-                         Branch.open(os.path.join(self._tmpdir, 
+        self.run_bzr(['baz-import-branch', os.path.join(self._tmpdir,
+                      'output3'), 'demo@DONOTUSE/c--0'])
+        self.assertEqual(['Arch-1:demo@DONOTUSE%c--0--base-0'],
+                         Branch.open(os.path.join(self._tmpdir,
                                      'output3')).revision_history())
-        self.run_bzr('baz-import-branch', os.path.join(self._tmpdir, 
-                      'output4'), 'demo@DONOTUSE/c--0', '--encoding', 'utf-8')
-        self.assertEqual(['Arch-1-utf-8:demo@DONOTUSE%c--0--base-0'], 
-                         Branch.open(os.path.join(self._tmpdir, 
+        self.run_bzr(['baz-import-branch', os.path.join(self._tmpdir,
+                      'output4'), 'demo@DONOTUSE/c--0', '--encoding', 'utf-8'])
+        self.assertEqual(['Arch-1-utf-8:demo@DONOTUSE%c--0--base-0'],
+                         Branch.open(os.path.join(self._tmpdir,
                                      'output4')).revision_history())
